summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmbumpmapedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmbumpmapedit.h')
-rw-r--r--kpovmodeler/pmbumpmapedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmbumpmapedit.h b/kpovmodeler/pmbumpmapedit.h
index 8404229b..0c29ca67 100644
--- a/kpovmodeler/pmbumpmapedit.h
+++ b/kpovmodeler/pmbumpmapedit.h
@@ -49,9 +49,9 @@ class PMBumpMapEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMBumpMapEdit with tqparent and name
*/
- PMBumpMapEdit( TQWidget* tqparent, const char* name = 0 );
+ PMBumpMapEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
/** */
@@ -49,9 +49,9 @@ class PMBumpMapEdit : public PMDialogEditBase
public:
/**
- * Creates a PMBumpMapEdit with tqparent and name
+ * Creates a PMBumpMapEdit with parent and name
*/